==> habitat-1.0.26-sources.jar: org/iworkz/habitat/entity/EntityFieldDefinition.java <==
package org.iworkz.habitat.entity;

import javax.inject.Inject;

import org.iworkz.habitat.dao.FieldType;
import org.iworkz.habitat.dialect.DatabaseDialect;


public class EntityFieldDefinition {
	
	private final String name;
	final String objectFieldName;
	private final FieldType type;
	private Integer constraint1;
	private Integer constraint2;
	boolean notNull;
	boolean versionField;
	boolean primaryKeyField;
	private final FieldValueStrategy valueStrategy;
	
	private DatabaseDialect databaseDialect;
	
	public EntityFieldDefinition(DatabaseDialect databaseDialect, String name, String objectFieldName, FieldType type, FieldValueStrategy fieldValueStrategy, boolean notNull) {
		this.databaseDialect = databaseDialect;
		this.name = name;
		this.objectFieldName = objectFieldName;
		this.type = type;
		this.valueStrategy = fieldValueStrategy;
		this.notNull = notNull;
	}
	
	public EntityFieldDefinition(DatabaseDialect databaseDialect, String name, String objectFieldName, FieldType type, FieldValueStrategy fieldValueStrategy) {
		this(databaseDialect,name,objectFieldName,type,fieldValueStrategy,false);
	}
	
	public EntityFieldDefinition(DatabaseDialect databaseDialect, String name, String objectFieldName, FieldType type, FieldValueStrategy fieldValueStrategy, Integer constraint1, boolean notNull) {
		this(databaseDialect,name,objectFieldName,type,fieldValueStrategy,notNull);
		this.constraint1 = constraint1;
	}
	
	public EntityFieldDefinition(DatabaseDialect databaseDialect, String name, String objectFieldName, FieldType type, FieldValueStrategy fieldValueStrategy, Integer constraint1) {
		this(databaseDialect,name,objectFieldName,type,fieldValueStrategy);
		this.constraint1 = constraint1;
	}

	public Integer getConstraint1() {
		return constraint1;
	}

	public void setConstraint1(Integer constraint1) {
		this.constraint1 = constraint1;
	}

	public Integer getConstraint2() {
		return constraint2;
	}

	public void setConstraint2(Integer constraint2) {
		this.constraint2 = constraint2;
	}

	public String getName() {
		return name;
	}

	public FieldType getType() {
		return type;
	}
	
	public String getTypeName() {
		return databaseDialect.getTypeName(this);
	}

	public String getConstraintsSql() {
		if (constraint1 != null) {
			if (constraint2 != null) {
				return "("+constraint1+","+constraint2+")";
			} else {
				return "("+constraint1+")";
			}
		}
		return "";
	}
	
	public String getNotNullSql() {
		if (notNull) {
			return " NOT NULL";
		}
		return "";
	}

	public boolean isVersionField() {
		return versionField;
	}

	public void setVersionField(boolean versionField) {
		this.versionField = versionField;
	}

	public boolean isPrimaryKeyField() {
		return primaryKeyField;
	}

	public void setPrimaryKeyField(boolean primaryKeyField) {
		this.primaryKeyField = primaryKeyField;
	}

	public FieldValueStrategy getValueStrategy() {
		return valueStrategy;
	}
	
}

==> habitat-1.0.29-sources.jar: org/iworkz/habitat/entity/EntityFieldDefinition.java <==
package org.iworkz.habitat.entity;

import javax.inject.Inject;

import org.iworkz.habitat.dao.FieldType;
import org.iworkz.habitat.dialect.DatabaseDialect;


public class EntityFieldDefinition {
	
	private final String name;
	final String objectFieldName;
	private final FieldType type;
	private Integer constraint1;
	private Integer constraint2;
	boolean notNull;
	boolean versionField;
	boolean primaryKeyField;
	private final FieldValueStrategy valueStrategy;
	
	private DatabaseDialect databaseDialect;
	
	public EntityFieldDefinition(DatabaseDialect databaseDialect, String name, String objectFieldName, FieldType type, FieldValueStrategy fieldValueStrategy, boolean notNull) {
		this.databaseDialect = databaseDialect;
		this.name = name;
		this.objectFieldName = objectFieldName;
		this.type = type;
		this.valueStrategy = fieldValueStrategy;
		this.notNull = notNull;
	}
	
	public EntityFieldDefinition(DatabaseDialect databaseDialect, String name, String objectFieldName, FieldType type, FieldValueStrategy fieldValueStrategy) {
		this(databaseDialect,name,objectFieldName,type,fieldValueStrategy,false);
	}
	
	public EntityFieldDefinition(DatabaseDialect databaseDialect, String name, String objectFieldName, FieldType type, FieldValueStrategy fieldValueStrategy, Integer constraint1, boolean notNull) {
		this(databaseDialect,name,objectFieldName,type,fieldValueStrategy,notNull);
		this.constraint1 = constraint1;
	}
	
	public EntityFieldDefinition(DatabaseDialect databaseDialect, String name, String objectFieldName, FieldType type, FieldValueStrategy fieldValueStrategy, Integer constraint1) {
		this(databaseDialect,name,objectFieldName,type,fieldValueStrategy);
		this.constraint1 = constraint1;
	}

	public Integer getConstraint1() {
		return constraint1;
	}

	public void setConstraint1(Integer constraint1) {
		this.constraint1 = constraint1;
	}

	public Integer getConstraint2() {
		return constraint2;
	}

	public void setConstraint2(Integer constraint2) {
		this.constraint2 = constraint2;
	}

	public String getName() {
		return name;
	}

	public FieldType getType() {
		return type;
	}
	
	public String getTypeName() {
		return databaseDialect.getTypeName(this);
	}

	public String getConstraintsSql() {
		return databaseDialect.getConstraintsSql(this);
	}
	
	public String getNotNullSql() {
		if (notNull) {
			return " NOT NULL";
		}
		return "";
	}

	public boolean isVersionField() {
		return versionField;
	}

	public void setVersionField(boolean versionField) {
		this.versionField = versionField;
	}

	public boolean isPrimaryKeyField() {
		return primaryKeyField;
	}

	public void setPrimaryKeyField(boolean primaryKeyField) {
		this.primaryKeyField = primaryKeyField;
	}

	public FieldValueStrategy getValueStrategy() {
		return valueStrategy;
	}
	
}
